==> flutter_query-0.1.15.tar.gz: lib/src/hooks.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:flutter_query/flutter_query.dart';
import 'package:flutter_query/src/query_cache.dart';
import 'package:flutter_query/src/types.dart';
import 'package:provider/provider.dart';

typedef Future<T> QueryFunction<T>();
typedef Future PageableQueryFunction<T>(T latestPage, List<T> allPages);
typedef dynamic GetFetchMoreFunction(latestPage, allPages);

typedef void QueryCallback<T>(T data);

QueryResult useQuery<T>(
  String key,
  QueryFunction<T> fn, {
  int cacheTime,
  bool enabled = true,
  dynamic initialData,
  dynamic initialStale,
  Function isDataEqual,
  bool keepPreviousData = false,
  bool notifyOnStatusChange = true,
  QueryCallback onSuccess,
  QueryCallback onError,
  QueryCallback onSettled,
  Function queryFnParamsFilter,
  Function queryKeySerializerFn,
  dynamic refetchInterval, // bool | int
  bool refetchIntervalInBackground,
  bool refetchOnMount = true,
  bool refetchOnReconnect = true,
  dynamic retry, // bool | int | Function
  int retryDelay,
  double staleTime,
  bool structuralSharing,
  bool useErrorBoundary,
}) {
  return use(
    _QueryHook(
      ResolvedQueryConfig(
        enabled: enabled,
        initialData: initialData,
        initialStale: initialStale,
        isDataEqual: isDataEqual,
        keepPreviousData: keepPreviousData,
        notifyOnStatusChange: notifyOnStatusChange,
        queryFnParamsFilter: queryFnParamsFilter,
        queryKeySerializerFn: queryKeySerializerFn,
        refetchOnMount: refetchOnMount,
        refetchOnReconnect: refetchOnReconnect,
        retry: retry,
        retryDelay: retryDelay,
        staleTime: staleTime ?? 0,
        structuralSharing: structuralSharing,
        useErrorBoundary: useErrorBoundary,
        queryKey: key,
        queryFn: fn,
        // TODO: This isn't actually valid
        queryHash: key,
        onSuccess: onSuccess,
        onError: onError,
        onSettled: onSettled,
        refetchInterval: refetchInterval,
        refetchIntervalInBackground: refetchIntervalInBackground,
        cacheTime: cacheTime ?? 5 * 60 * 1000,
      ),
    ),
  );
}

QueryResult useInfiniteQuery<T>(
  String key,
  PageableQueryFunction<T> fn, {
  GetFetchMoreFunction getFetchMore,
  int cacheTime,
  bool enabled = true,
  dynamic initialData,
  dynamic initialStale,
  Function isDataEqual,
  bool keepPreviousData = false,
  bool notifyOnStatusChange = true,
  QueryCallback onSuccess,
  QueryCallback onError,
  QueryCallback onSettled,
  Function queryFnParamsFilter,
  Function queryKeySerializerFn,
  dynamic refetchInterval, // bool | int
  bool refetchIntervalInBackground,
  bool refetchOnMount = true,
  bool refetchOnReconnect = true,
  dynamic retry, // bool | int | Function
  int retryDelay,
  double staleTime,
  bool structuralSharing,
  bool useErrorBoundary,
}) {
  return use(
    _QueryHook(
      ResolvedQueryConfig(
        enabled: enabled,
        initialData: initialData,
        initialStale: initialStale,
        isDataEqual: isDataEqual,
        keepPreviousData: keepPreviousData,
        notifyOnStatusChange: notifyOnStatusChange,
        queryFnParamsFilter: queryFnParamsFilter,
        queryKeySerializerFn: queryKeySerializerFn,
        refetchOnMount: refetchOnMount,
        refetchOnReconnect: refetchOnReconnect,
        retry: retry,
        retryDelay: retryDelay,
        staleTime: staleTime ?? 0,
        structuralSharing: structuralSharing,
        useErrorBoundary: useErrorBoundary,
        queryKey: key,
        queryFn: fn,
        // TODO: This isn't actually valid
        queryHash: key,
        infinite: true,
        getFetchMore: getFetchMore,
        onSuccess: onSuccess,
        onError: onError,
        onSettled: onSettled,
        refetchInterval: refetchInterval,
        refetchIntervalInBackground: refetchIntervalInBackground,
        cacheTime: cacheTime ?? 5 * 60 * 1000,
      ),
    ),
  );
}

class _QueryHook extends Hook<QueryResult> {
  const _QueryHook(this.config);

  final ResolvedQueryConfig config;

  @override
  _QueryStateHook createState() => _QueryStateHook();
}

class _QueryStateHook extends HookState<QueryResult, _QueryHook> {
  QueryResult _result;
  Function _unsubscribe;

  @override
  void initHook() {
    super.initHook();
    final cache = Provider.of<QueryCache>(context, listen: false);
    hook.config.queryCache = cache;

    final observer = QueryObserver(hook.config);
    _result = observer.currentResult;

    _unsubscribe = observer.subscribe((result) {
      setState(() {
        _result = result;
      });
    });
  }

  @override
  void dispose() {
    super.dispose();
    _unsubscribe();
  }

  @override
  QueryResult build(BuildContext context) {
    return _result;
  }
}

class QueryCacheProvider extends StatefulWidget {
  final Widget child;
  QueryCacheProvider({this.child});

  @override
  State<StatefulWidget> createState() => QueryCacheProviderState();
}

class QueryCacheProviderState extends State<QueryCacheProvider> {
  QueryCache _queryCache;

  @override
  void initState() {
    _queryCache = QueryCache();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Provider.value(
      value: _queryCache,
      child: widget.child,
    );
  }
}

==> flutter_query-0.1.17.tar.gz: lib/src/hooks.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:flutter_query/flutter_query.dart';
import 'package:flutter_query/src/query_cache.dart';
import 'package:flutter_query/src/types.dart';
import 'package:provider/provider.dart';

typedef Future<T> QueryFunction<T>();
typedef Future PageableQueryFunction<T>(int page);
typedef dynamic GetFetchMoreFunction(latestPage, allPages);

typedef void QueryCallback<T>(T data);

QueryResult useQuery<T>(
  String key,
  QueryFunction<T> fn, {
  int cacheTime,
  bool enabled = true,
  dynamic initialData,
  dynamic initialStale,
  Function isDataEqual,
  bool keepPreviousData = false,
  bool notifyOnStatusChange = true,
  QueryCallback onSuccess,
  QueryCallback onError,
  QueryCallback onSettled,
  Function queryFnParamsFilter,
  Function queryKeySerializerFn,
  dynamic refetchInterval, // bool | int
  bool refetchIntervalInBackground,
  bool refetchOnMount = true,
  bool refetchOnReconnect = true,
  dynamic retry, // bool | int | Function
  int retryDelay,
  double staleTime,
  bool structuralSharing,
  bool useErrorBoundary,
}) {
  return use(
    _QueryHook(
      ResolvedQueryConfig(
        enabled: enabled,
        initialData: initialData,
        initialStale: initialStale,
        isDataEqual: isDataEqual,
        keepPreviousData: keepPreviousData,
        notifyOnStatusChange: notifyOnStatusChange,
        queryFnParamsFilter: queryFnParamsFilter,
        queryKeySerializerFn: queryKeySerializerFn,
        refetchOnMount: refetchOnMount,
        refetchOnReconnect: refetchOnReconnect,
        retry: retry,
        retryDelay: retryDelay,
        staleTime: staleTime ?? 0,
        structuralSharing: structuralSharing,
        useErrorBoundary: useErrorBoundary,
        queryKey: key,
        queryFn: fn,
        // TODO: This isn't actually valid
        queryHash: key,
        onSuccess: onSuccess,
        onError: onError,
        onSettled: onSettled,
        refetchInterval: refetchInterval,
        refetchIntervalInBackground: refetchIntervalInBackground,
        cacheTime: cacheTime ?? 5 * 60 * 1000,
      ),
    ),
  );
}

QueryResult useInfiniteQuery<T>(
  String key,
  PageableQueryFunction<T> fn, {
  GetFetchMoreFunction getFetchMore,
  int cacheTime,
  bool enabled = true,
  dynamic initialData,
  dynamic initialStale,
  Function isDataEqual,
  bool keepPreviousData = false,
  bool notifyOnStatusChange = true,
  QueryCallback onSuccess,
  QueryCallback onError,
  QueryCallback onSettled,
  Function queryFnParamsFilter,
  Function queryKeySerializerFn,
  dynamic refetchInterval, // bool | int
  bool refetchIntervalInBackground,
  bool refetchOnMount = true,
  bool refetchOnReconnect = true,
  dynamic retry, // bool | int | Function
  int retryDelay,
  double staleTime,
  bool structuralSharing,
  bool useErrorBoundary,
}) {
  return use(
    _QueryHook(
      ResolvedQueryConfig(
        enabled: enabled,
        initialData: initialData,
        initialStale: initialStale,
        isDataEqual: isDataEqual,
        keepPreviousData: keepPreviousData,
        notifyOnStatusChange: notifyOnStatusChange,
        queryFnParamsFilter: queryFnParamsFilter,
        queryKeySerializerFn: queryKeySerializerFn,
        refetchOnMount: refetchOnMount,
        refetchOnReconnect: refetchOnReconnect,
        retry: retry,
        retryDelay: retryDelay,
        staleTime: staleTime ?? 0,
        structuralSharing: structuralSharing,
        useErrorBoundary: useErrorBoundary,
        queryKey: key,
        queryFn: fn,
        // TODO: This isn't actually valid
        queryHash: key,
        infinite: true,
        getFetchMore: getFetchMore,
        onSuccess: onSuccess,
        onError: onError,
        onSettled: onSettled,
        refetchInterval: refetchInterval,
        refetchIntervalInBackground: refetchIntervalInBackground,
        cacheTime: cacheTime ?? 5 * 60 * 1000,
      ),
    ),
  );
}

class _QueryHook extends Hook<QueryResult> {
  const _QueryHook(this.config);

  final ResolvedQueryConfig config;

  @override
  _QueryStateHook createState() => _QueryStateHook();
}

class _QueryStateHook extends HookState<QueryResult, _QueryHook> {
  QueryResult _result;
  Function _unsubscribe;

  @override
  void initHook() {
    super.initHook();
    final cache = Provider.of<QueryCache>(context, listen: false);
    hook.config.queryCache = cache;

    final observer = QueryObserver(hook.config);
    _result = observer.currentResult;

    _unsubscribe = observer.subscribe((result) {
      setState(() {
        _result = result;
      });
    });
  }

  @override
  void dispose() {
    super.dispose();
    _unsubscribe();
  }

  @override
  QueryResult build(BuildContext context) {
    return _result;
  }
}

class QueryCacheProvider extends StatefulWidget {
  final Widget child;
  QueryCacheProvider({this.child});

  @override
  State<StatefulWidget> createState() => QueryCacheProviderState();
}

class QueryCacheProviderState extends State<QueryCacheProvider> {
  QueryCache _queryCache;

  @override
  void initState() {
    _queryCache = QueryCache();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Provider.value(
      value: _queryCache,
      child: widget.child,
    );
  }
}
